/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

var App = require('app');
require('controllers/main/views_controller');

describe('MainViewsController', function () {

  var mainViewsController = App.MainViewsController.create();

  describe('#loadAmbariViews()', function () {
    beforeEach(function () {
      sinon.stub(App.ajax, 'send', Em.K);
    });
    afterEach(function () {
      App.router.get.restore();
      App.ajax.send.restore();
    });

    it('should load views if the user is logged in', function () {
      sinon.stub(App.router, 'get').withArgs('loggedIn').returns(true);
      mainViewsController.loadAmbariViews();
      expect(App.ajax.send.calledOnce).to.be.true;
    });

    it('should not load views if the user is not logged in', function () {
      sinon.stub(App.router, 'get').withArgs('loggedIn').returns(false);
      mainViewsController.loadAmbariViews();
      expect(App.ajax.send.notCalled).to.be.true;
    })
  });

});
